@@ -1,22 +1,19 @@
 # ABSTRACT: Additional helper hook routines
 package App::CharmKit;
 
-our $VERSION = '2.10';
-
 use charm;
-
-use FindBin;
 use base "Exporter::Tiny";
+use FindBin;
+use lib "$FindBin::Bin/..lib";
+use Module::Runtime qw(use_package_optimistically);
 
-our @EXPORT = qw(plugin);
+our $VERSION = '2.11';
+our @EXPORT  = qw(plugin);
 
 sub plugin ($name, $opts = {}) {
-    my $name_path = "$FindBin::Bin/../lib/$name.pm";
-    require $name_path;
-    return "$name"->new($opts);
+    return use_package_optimistically("$name")->new($opts);
 }
 
-
 1;
 
 __END__
@@ -33,8 +30,8 @@ App::CharmKit - ez pz charm authoring
     #
     # In hooks/install
     BEGIN {
-      system "apt-get install cpanminus";
-      system "cpanm -n App::CharmKit";
+      system "apt-get install -qyf cpanminus";
+      system "cpanm -qn App::CharmKit";
     }
 
     use charm;
@@ -46,7 +43,7 @@ App::CharmKit - ez pz charm authoring
 
     file "/etc/systemd/system/znc.service", source => "$hook_path/templates/znc.service";
 
-    my $content = template("$hook_path/templates/znc.conf", port => config 'port');
+    my $content = template("$hook_path/templates/znc.conf", port => sh 'config-get port');
     file "/home/ubuntu/.znc/configs", ensure => "directory", owner => "ubuntu", group => "ubuntu";
     file "/home/ubuntu/.znc/configs/znc.conf",
       owner     => "ubuntu",
